package com.myorg;

import software.amazon.awscdk.customresources.*;
import software.amazon.awscdk.services.ssm.StringParameter;
import software.constructs.Construct;
import software.amazon.awscdk.Stack;
import software.amazon.awscdk.StackProps;

import java.util.Date;
import java.util.Collections;
import java.util.Map;

public class BugReportStack extends Stack {
    public BugReportStack(final Construct scope, final String id) {
        this(scope, id, null);
    }

    public BugReportStack(final Construct scope, final String id, final StackProps props) {
        super(scope, id, props);
        final String albSsmParameter="some_alb";
        final String ssmArn = "arn:aws:ssm:us-east-1:"+props.getEnv().getAccount()+":parameter/some_alb";
        final String albArn="arn:aws:elasticloadbalancing:us-east-1:"+props.getEnv().getAccount()+":loadbalancer/app/sandbox-alb/6f09204312f7d123";
        final String permissiveAccessToLb= "arn:aws:elasticloadbalancing:us-east-1:"+props.getEnv().getAccount()+":loadbalancer/*";

        StringParameter.Builder.create(this, albSsmParameter)
                .parameterName(albSsmParameter)
                .description("a sample ssm parameter with an arn value")
                .stringValue(albArn)
                .build();

        AwsCustomResource  albArnCustomResource = AwsCustomResource.Builder.create(this, "resource_one")
                .onUpdate(AwsSdkCall.builder()
                        .service("SSM")
                        .region(this.getRegion())
                        .action("getParameter")
                        .parameters( Map.of("Name", albSsmParameter))
                        .physicalResourceId(PhysicalResourceId.of(new Date().toString()))
                        .build())
                .policy(AwsCustomResourcePolicy.fromSdkCalls(SdkCallsPolicyOptions.builder().resources(Collections.singletonList(ssmArn)).build()))
                .build();

        AwsCustomResource albListenersCustomResource = AwsCustomResource.Builder.create(this, "resource two")
                .onUpdate(AwsSdkCall.builder()
                        .service("ELBv2")
                        .region(this.getRegion())
                        .action("describeListeners")
                        .parameters( Map.of (
                                "LoadBalancerArn", albArnCustomResource.getResponseField("Parameter.Value") ))
                        .physicalResourceId(PhysicalResourceId.of(new Date().toString()))
                        .build())
                        .policy(AwsCustomResourcePolicy.fromSdkCalls(SdkCallsPolicyOptions.builder().resources(Collections.singletonList(permissiveAccessToLb)).build()))
                        .build();
    }
}
